import Link from "next/link";
import { ArrowRight, CheckCircle2, Code2, Lock, Users } from "lucide-react";

import { Button } from "@/components/ui/button";
import {
  Card,
  CardContent,
  CardDescription,
  CardHeader,
  CardTitle,
} from "@/components/ui/card";
import { Container } from "@/components/ui/container";
import { Section } from "@/components/ui/section";
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs";
import {
  TypographyH1,
  TypographyH2,
  TypographyLead,
  TypographyMuted,
} from "@/components/ui/typography";
import { Header } from "@/components/layout/header";

export default function HomePage() {
  return (
    <div className="flex min-h-screen flex-col">
      <Header />
      <main className="flex-1">
        {/* Hero Section */}
        <Section className="relative overflow-hidden bg-gradient-to-b from-white to-gray-50 pb-16 pt-24 dark:from-gray-900 dark:to-gray-800">
          <div className="absolute inset-0">
            <div className="bg-grid-black/[0.02] dark:bg-grid-white/[0.02] absolute inset-0" />
          </div>
          <Container>
            <div className="relative flex flex-col items-center justify-center space-y-8 text-center">
              <div className="space-y-6">
                <h1 className="text-4xl font-bold tracking-tighter text-gray-900 dark:text-white sm:text-5xl md:text-6xl lg:text-7xl">
                  Q58 Connect
                </h1>
                <div className="mx-auto max-w-[800px] px-4">
                  <p className="text-base text-gray-500 dark:text-gray-400 sm:text-lg md:text-xl">
                    基于 OAuth 2.0 协议，为您的应用快速接入 Q58
                    论坛统一身份认证，实现一键登录
                  </p>
                </div>
              </div>
              <div className="flex gap-4">
                <Link href="/sign-in">
                  <Button size="lg" className="gap-2">
                    开始使用
                    <ArrowRight className="h-5 w-5" />
                  </Button>
                </Link>
              </div>
            </div>
          </Container>
        </Section>

        {/* Features Section */}
        <Section className="bg-white py-24 dark:bg-gray-900">
          <Container>
            <div className="grid gap-8 md:grid-cols-3">
              <Card className="border-2 bg-white/50 transition-colors hover:border-primary/50 dark:bg-gray-800/50">
                <CardHeader>
                  <Code2 className="h-10 w-10 text-primary" />
                  <CardTitle className="text-xl">简单集成</CardTitle>
                  <CardDescription className="text-base">
                    只需几行代码，即可为您的应用添加 Q58 论坛账号登录功能
                  </CardDescription>
                </CardHeader>
                <CardContent>
                  <ul className="space-y-4 text-sm">
                    <li className="flex items-center gap-2">
                      <CheckCircle2 className="h-5 w-5 text-green-500" />
                      <span>标准 OAuth 2.0 协议</span>
                    </li>
                    <li className="flex items-center gap-2">
                      <CheckCircle2 className="h-5 w-5 text-green-500" />
                      <span>完整的开发文档</span>
                    </li>
                    <li className="flex items-center gap-2">
                      <CheckCircle2 className="h-5 w-5 text-green-500" />
                      <span>示例代码和SDK</span>
                    </li>
                  </ul>
                </CardContent>
              </Card>

              <Card className="border-2 bg-white/50 transition-colors hover:border-primary/50 dark:bg-gray-800/50">
                <CardHeader>
                  <Lock className="h-10 w-10 text-primary" />
                  <CardTitle className="text-xl">安全可靠</CardTitle>
                  <CardDescription className="text-base">
                    采用业界最佳实践，确保您的应用和用户数据安全
                  </CardDescription>
                </CardHeader>
                <CardContent>
                  <ul className="space-y-4 text-sm">
                    <li className="flex items-center gap-2">
                      <CheckCircle2 className="h-5 w-5 text-green-500" />
                      <span>HTTPS 加密传输</span>
                    </li>
                    <li className="flex items-center gap-2">
                      <CheckCircle2 className="h-5 w-5 text-green-500" />
                      <span>授权码+令牌双重验证</span>
                    </li>
                    <li className="flex items-center gap-2">
                      <CheckCircle2 className="h-5 w-5 text-green-500" />
                      <span>防CSRF攻击</span>
                    </li>
                  </ul>
                </CardContent>
              </Card>

              <Card className="border-2 bg-white/50 transition-colors hover:border-primary/50 dark:bg-gray-800/50">
                <CardHeader>
                  <Users className="h-10 w-10 text-primary" />
                  <CardTitle className="text-xl">功能丰富</CardTitle>
                  <CardDescription className="text-base">
                    提供完整的用户信息和权限管理功能
                  </CardDescription>
                </CardHeader>
                <CardContent>
                  <ul className="space-y-4 text-sm">
                    <li className="flex items-center gap-2">
                      <CheckCircle2 className="h-5 w-5 text-green-500" />
                      <span>用户基本信息</span>
                    </li>
                    <li className="flex items-center gap-2">
                      <CheckCircle2 className="h-5 w-5 text-green-500" />
                      <span>用户组权限</span>
                    </li>
                    <li className="flex items-center gap-2">
                      <CheckCircle2 className="h-5 w-5 text-green-500" />
                      <span>管理员特权</span>
                    </li>
                  </ul>
                </CardContent>
              </Card>
            </div>
          </Container>
        </Section>

        {/* Documentation Section */}
        <Section className="border-t bg-gray-50 py-24 dark:bg-gray-800">
          <Container>
            <div className="mx-auto max-w-4xl">
              <Card className="overflow-hidden border-2 p-6">
                <CardHeader className="bg-white dark:bg-gray-900">
                  <CardTitle className="text-2xl">快速开始</CardTitle>
                  <CardDescription className="text-base">
                    按照以下步骤，快速接入 Q58 Connect
                  </CardDescription>
                </CardHeader>
                <CardContent className="bg-white p-0 dark:bg-gray-900">
                  <Tabs defaultValue="auth" className="w-full">
                    <TabsList className="grid w-full grid-cols-3">
                      <TabsTrigger value="auth">发起授权</TabsTrigger>
                      <TabsTrigger value="callback">处理回调</TabsTrigger>
                      <TabsTrigger value="userinfo">获取用户</TabsTrigger>
                    </TabsList>
                    <TabsContent value="auth" className="mt-4">
                      <Card>
                        <CardHeader>
                          <CardTitle>1. 发起授权请求</CardTitle>
                          <CardDescription>
                            将用户重定向到授权页面
                          </CardDescription>
                        </CardHeader>
                        <CardContent>
                          <pre className="overflow-x-auto rounded-lg bg-gray-100 p-4 dark:bg-gray-800">
                            <code className="text-sm">
                              {`const authUrl = 'https://connect.q58.club/oauth/authorize?' + 
  new URLSearchParams({
    response_type: 'code',        // 必填，固定值
    client_id: 'your_client_id',  // 必填，您的应用ID
    redirect_uri: 'https://your-app.com/callback',
    state: 'random_state',        // 建议提供，防CSRF攻击
    scope: 'read_profile'         // 可选，默认read_profile
  });

window.location.href = authUrl;`}
                            </code>
                          </pre>
                        </CardContent>
                      </Card>
                    </TabsContent>
                    <TabsContent value="callback" className="mt-4">
                      <Card>
                        <CardHeader>
                          <CardTitle>2. 处理授权回调</CardTitle>
                          <CardDescription>
                            在回调地址处理授权结果
                          </CardDescription>
                        </CardHeader>
                        <CardContent>
                          <pre className="overflow-x-auto rounded-lg bg-gray-100 p-4 dark:bg-gray-800">
                            <code className="text-sm">
                              {`// 获取访问令牌
const response = await fetch('https://connect.q58.club/api/oauth/access_token', {
  method: 'POST',
  headers: {
    'Content-Type': 'application/x-www-form-urlencoded'
  },
  body: new URLSearchParams({
    code: '授权码',  // 回调参数中的code
    redirect_uri: 'https://your-app.com/callback'
  })
});

const { access_token, expires_in } = await response.json();`}
                            </code>
                          </pre>
                        </CardContent>
                      </Card>
                    </TabsContent>
                    <TabsContent value="userinfo" className="mt-4">
                      <Card>
                        <CardHeader>
                          <CardTitle>3. 获取用户信息</CardTitle>
                          <CardDescription>
                            使用访问令牌获取用户数据
                          </CardDescription>
                        </CardHeader>
                        <CardContent>
                          <pre className="overflow-x-auto rounded-lg bg-gray-100 p-4 dark:bg-gray-800">
                            <code className="text-sm">
                              {`const userInfo = await fetch('https://connect.q58.club/api/oauth/user', {
  headers: {
    'Authorization': \`Bearer \${access_token}\`
  }
}).then(res => res.json());

// 返回数据示例:
{
  "id": "user_xxx",
  "email": "user@example.com",
  "username": "username",
  "name": "用户昵称",
  "avatar_url": "https://...",
  "groups": ["group1", "group2"]
}`}
                            </code>
                          </pre>
                        </CardContent>
                      </Card>
                    </TabsContent>
                  </Tabs>
                </CardContent>
              </Card>
            </div>
          </Container>
        </Section>

        {/* CTA Section */}
        <Section className="bg-white py-24 dark:bg-gray-900">
          <Container>
            <div className="text-center">
              <h2 className="text-3xl font-bold">准备好了吗？</h2>
              <p className="mt-2 text-gray-500 dark:text-gray-400">
                创建一个应用，开始使用 Q58 Connect
              </p>
              <div className="mt-8">
                <Link href="/sign-in">
                  <Button size="lg" className="min-w-[200px]">
                    立即开始
                  </Button>
                </Link>
              </div>
            </div>
          </Container>
        </Section>
      </main>

      <footer className="border-t bg-white py-12 dark:bg-gray-900">
        <Container>
          <div className="text-center text-sm text-gray-500 dark:text-gray-400">
            © 2024{" "}
            <a
              href="https://q58.club"
              className="text-[#25263A] hover:underline dark:text-[#A0A1B2]"
            >
              Q58论坛
            </a>
            . 保留所有权利。
          </div>
        </Container>
      </footer>
    </div>
  );
}
